*************
API reference
*************

.. warning::

   This documentation is work-in-progress; incomplete and unorganized.

.. automodule:: weave
   :members:


.. autosummary::
   :toctree: generated/

   inline
